@@ -1,8 +1,8 @@
 from dagster.core.utils import check_dagster_package_version
 
-from .config import get_celery_engine_config
-from .job import DagsterK8sJobConfig, construct_dagster_graphql_k8s_job
-from .launcher import CeleryK8sRunLauncher, K8sRunLauncher
+from .job import DagsterK8sJobConfig, construct_dagster_k8s_job
+from .launcher import K8sRunLauncher
+from .scheduler import K8sScheduler
 from .version import __version__
 
 check_dagster_package_version('dagster-k8s', __version__)
