@@ -15,15 +15,41 @@ def get_pod_names_in_job(job_name, namespace):
     return DagsterKubernetesClient.production_client().get_pod_names_in_job(job_name, namespace)
 
 
+def delete_job(job_name, namespace):
+    return DagsterKubernetesClient.production_client().delete_job(job_name, namespace)
+
+
 def wait_for_job_success(
     job_name,
     namespace,
+    instance=None,
+    run_id=None,
     wait_timeout=DEFAULT_WAIT_TIMEOUT,
     wait_time_between_attempts=DEFAULT_WAIT_BETWEEN_ATTEMPTS,
     num_pods_to_wait_for=DEFAULT_JOB_POD_COUNT,
 ):
     return DagsterKubernetesClient.production_client().wait_for_job_success(
-        job_name, namespace, wait_timeout, wait_time_between_attempts, num_pods_to_wait_for
+        job_name,
+        namespace,
+        instance,
+        run_id,
+        wait_timeout,
+        wait_time_between_attempts,
+        num_pods_to_wait_for,
+    )
+
+
+def wait_for_job(
+    job_name,
+    namespace,
+    wait_timeout=DEFAULT_WAIT_TIMEOUT,
+    wait_time_between_attempts=DEFAULT_WAIT_BETWEEN_ATTEMPTS,
+):
+    return DagsterKubernetesClient.production_client().wait_for_job(
+        job_name=job_name,
+        namespace=namespace,
+        wait_timeout=wait_timeout,
+        wait_time_between_attempts=wait_time_between_attempts,
     )
 
 
